@@ -3,7 +3,7 @@
 // Author      : Avi
 // Revision    : $Revision: #305 $ 
 //
-// Copyright 2009-2020 ECMWF.
+// Copyright 2009- ECMWF.
 // This software is licensed under the terms of the Apache Licence version 2.0 
 // which can be obtained at http://www.apache.org/licenses/LICENSE-2.0. 
 // In applying this licence, ECMWF does not waive the privileges and immunities 
@@ -741,7 +741,7 @@ bool Node::evaluateComplete() const
    if (theCompeteAst) {
       // *NOTE* if we have a non NULL complete ast, we must have complete expression
       // The freed state is stored on the expression ( i.e not on the ast)
-      // ISSUE: Complete expression can not be by-passed in the GUI
+      // ISSUE: Complete expression cannot be by-passed in the GUI
       if (c_expr_->isFree() || theCompeteAst->evaluate()) {
 
          // Note: if a task has been set complete, the use may decide to place into queued state( via GUI)
@@ -2421,7 +2421,7 @@ void Node::notify_delete()
    }
 
    /// Check to make sure that the Observer called detach
-   /// We can not call detach ourselves, since the the client needs to
+   /// We cannot call detach ourselves, since the the client needs to
    /// call detach in the case where the graphical tree is destroyed by user
    /// In this case the Subject/Node is being deleted.
    assert(observers_.empty());
@@ -2542,20 +2542,19 @@ bool Node::checkForAutoCancel(const ecf::Calendar& calendar) const
 
 bool Node::check_for_auto_archive(const ecf::Calendar& calendar) const
 {
-   if ( auto_archive_ && state() == NState::COMPLETE) {
-      if (!isSuspended() && auto_archive_->isFree(calendar,get_state().second)) {
-         if (!isParentSuspended()) {
+   if ( auto_archive_ && !isSuspended() && !isParentSuspended()) {
+      if (auto_archive_->isFree(calendar,get_state())) {
 
-            /// *Only* archive this node if we don't create zombies anywhere for our children
-            vector<Task*> taskVec;
-            getAllTasks(taskVec);
-            for(Task* t: taskVec) {
-               if (t->state() == NState::ACTIVE || t->state() == NState::SUBMITTED) {
-                  return false;
-               }
+         /// *Only* archive this node if we don't create zombies anywhere for our children
+         /// The most significant state could be ABORTED in family, but we could still have active tasks.
+         vector<Task*> taskVec;
+         getAllTasks(taskVec);
+         for(Task* t: taskVec) {
+            if (t->state() == NState::ACTIVE || t->state() == NState::SUBMITTED) {
+               return false;
             }
-            return true;
          }
+         return true;
       }
    }
    return false;
