@@ -1,5 +1,5 @@
 //============================================================================
-// Copyright 2009-2018 ECMWF.
+// Copyright 2009- ECMWF.
 // This software is licensed under the terms of the Apache Licence version 2.0
 // which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
 // In applying this licence, ECMWF does not waive the privileges and immunities
@@ -15,6 +15,7 @@
 #include <string>
 #include <vector>
 
+#include <QtGlobal>
 #include <QAbstractItemModel>
 #include <QByteArray>
 #include <QGraphicsItem>
@@ -24,7 +25,9 @@
 #include <QWidget>
 #include <QSortFilterProxyModel>
 #include <QtCharts>
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 using namespace QtCharts;
+#endif
 
 #include "LogLoadData.hpp"
 
